@@ -445,23 +445,27 @@ Error ImageItem_Grid::decode_and_paste_tile_image(heif_item_id tileID, uint32_t
 
   // --- generate the image canvas for combining all the tiles
 
-  if (!inout_image) { // this if avoids that we normally have to lock a mutex
+  if (!inout_image) { // this avoids that we normally have to lock a mutex
+#if ENABLE_PARALLEL_TILE_DECODING
     static std::mutex createImageMutex;
     std::lock_guard<std::mutex> lock(createImageMutex);
+#endif
 
     if (!inout_image) {
-      inout_image = std::make_shared<HeifPixelImage>();
-      inout_image->create_clone_image_at_new_size(tile_img, w, h);
+      auto grid_image = std::make_shared<HeifPixelImage>();
+      grid_image->create_clone_image_at_new_size(tile_img, w, h);
 
       // Fill alpha plane with opaque in case not all tiles have alpha planes
 
-      if (inout_image->has_channel(heif_channel_Alpha)) {
-        uint16_t alpha_bpp = inout_image->get_bits_per_pixel(heif_channel_Alpha);
+      if (grid_image->has_channel(heif_channel_Alpha)) {
+        uint16_t alpha_bpp = grid_image->get_bits_per_pixel(heif_channel_Alpha);
         assert(alpha_bpp <= 16);
 
         auto alpha_default_value = static_cast<uint16_t>((1UL << alpha_bpp) - 1UL);
-        inout_image->fill_plane(heif_channel_Alpha, alpha_default_value);
+        grid_image->fill_plane(heif_channel_Alpha, alpha_default_value);
       }
+
+      inout_image = grid_image; // We have to set this at the very end because of the unlocked check to `inout_image` above.
     }
   }
 
@@ -479,8 +483,10 @@ Error ImageItem_Grid::decode_and_paste_tile_image(heif_item_id tileID, uint32_t
   inout_image->copy_image_to(tile_img, x0, y0);
 
   if (options.on_progress) {
+#if ENABLE_PARALLEL_TILE_DECODING
     static std::mutex progressMutex;
     std::lock_guard<std::mutex> lock(progressMutex);
+#endif
 
     options.on_progress(heif_progress_step_total, ++progress_counter, options.progress_user_data);
   }
